###DOmake.ct.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
##
## Modified: T.Porteous Jun96-Added Web page support code
##
## Modified: R.L.Moe    Jan97 Correct name of Web Directory.
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

if ($#argv < 1) then
   echo "usage: DOmake.ct.page.plot   <date.ext>"
   echo " (produces profile ps file named ctfile.<date.ext>.ps)"
   exit
endif

### WEB PAGE-source cruise leg & define web dir
source /scgscg/files/CRUISE.LEG
# set WEB_DIR=/WEB_SITE/LEGS_database/CURRENT/$CRUISE/DAILY_PROFILES/CT
set WEB_DIR=/Web_Site/LEGS_database/CURRENT/$CRUISE/DAILY_PROFILES/CT

# Change these Lower/Upper ranges as necessary:
set SSV_RANGE     = 1515/1555   ; set SSV_TIC     = "a5g5f1:Sound Velocity (m/sec):"
set SAL_RANGE     = 30/40       ; set SAL_TIC     = "a5g5f1:Salinity (ppt):"
set H2OTEMP_RANGE = 15/40         ; set H2OTEMP_TIC = "a10g5f1:h2o temp C.:"

# Don't change these:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"

set PRINTr = qms

cd $DIRUWDATA/CT

set DATE = $1

#CTinfp file on mlvl61:
set SOURCE = /scgscg/files/PFILE/CTinpf.

rsh mlvl61 cat $SOURCE$DATE | /UWDSYS/bin/ctextr  > ctfile.$DATE
#

set IFN = ctfile.$DATE

if !( -e $IFN ) then
   echo Cannot find file $IFN \!  Exiting...
   exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = $IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.5
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.9
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "CT data  $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

set COL_HR = 2       ; set COL_H2OTEMP = 3      ; set COL_SAL = 4
set COL_SSV = 5

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`



###################### start 1st panel ######################################
set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/"$SSV_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$SSV_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_SSV
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$SAL_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$SAL_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_SAL
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

###################### start 3rd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$H2OTEMP_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$H2OTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_H2OTEMP
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -U/-0.5/-4.4/ -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
### finish off the postscript file ##########################################

#print the plot: copies for dproc, SCG, Lab
repeat 1 lp -s -d$PRINTr $OFN

## WEB PAGE-convert ps file to gif and place in web dir
cp $OFN ct.ps
alchemy ct.ps ct.gif -g -Zc1 -Zd 100 100 >& /dev/null
cp ct.gif $WEB_DIR/$IFN.gif
/usr/bin/rm ct.{ps,gif}

#compress files:
compress $IFN
#end
